# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class TestConfig(Base):
	"""The TestConfig class encapsulates a required testConfig node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the TestConfig property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'testConfig'

	def __init__(self, parent):
		super(TestConfig, self).__init__(parent)

	@property
	def BurstSize(self):
		"""The number of packets to send in a burst.

		Returns:
			number
		"""
		return self._get_attribute('burstSize')
	@BurstSize.setter
	def BurstSize(self, value):
		self._set_attribute('burstSize', value)

	@property
	def CalculateJitter(self):
		"""If true, calculates jitter.

		Returns:
			bool
		"""
		return self._get_attribute('calculateJitter')
	@CalculateJitter.setter
	def CalculateJitter(self, value):
		self._set_attribute('calculateJitter', value)

	@property
	def CalculateLatency(self):
		"""If true, calibrates the latency.

		Returns:
			bool
		"""
		return self._get_attribute('calculateLatency')
	@CalculateLatency.setter
	def CalculateLatency(self, value):
		self._set_attribute('calculateLatency', value)

	@property
	def DelayAfterTransmit(self):
		"""Specifies the amount of delay after every transmit.

		Returns:
			number
		"""
		return self._get_attribute('delayAfterTransmit')
	@DelayAfterTransmit.setter
	def DelayAfterTransmit(self, value):
		self._set_attribute('delayAfterTransmit', value)

	@property
	def DownstreamGrain(self):
		"""The type downstream grain.

		Returns:
			str(coarse|fine)
		"""
		return self._get_attribute('downstreamGrain')
	@DownstreamGrain.setter
	def DownstreamGrain(self, value):
		self._set_attribute('downstreamGrain', value)

	@property
	def DownstreamImixAdd(self):
		"""Adds the IMIX for downstream.

		Returns:
			str
		"""
		return self._get_attribute('downstreamImixAdd')
	@DownstreamImixAdd.setter
	def DownstreamImixAdd(self, value):
		self._set_attribute('downstreamImixAdd', value)

	@property
	def DownstreamImixData(self):
		"""Signifies the downstream IMIX data

		Returns:
			str
		"""
		return self._get_attribute('downstreamImixData')
	@DownstreamImixData.setter
	def DownstreamImixData(self, value):
		self._set_attribute('downstreamImixData', value)

	@property
	def DownstreamImixDataQoS(self):
		"""Signifies the quality of service for downstream IMIX data

		Returns:
			bool
		"""
		return self._get_attribute('downstreamImixDataQoS')
	@DownstreamImixDataQoS.setter
	def DownstreamImixDataQoS(self, value):
		self._set_attribute('downstreamImixDataQoS', value)

	@property
	def DownstreamImixDelete(self):
		"""Deletes the downstream IMIX value

		Returns:
			str
		"""
		return self._get_attribute('downstreamImixDelete')
	@DownstreamImixDelete.setter
	def DownstreamImixDelete(self, value):
		self._set_attribute('downstreamImixDelete', value)

	@property
	def DownstreamImixDistribution(self):
		"""It gives details about the down stream Imix distribution.

		Returns:
			str(bwpercentage|weight)
		"""
		return self._get_attribute('downstreamImixDistribution')
	@DownstreamImixDistribution.setter
	def DownstreamImixDistribution(self, value):
		self._set_attribute('downstreamImixDistribution', value)

	@property
	def DownstreamImixEnabled(self):
		"""If true, enables downstream IMIX

		Returns:
			bool
		"""
		return self._get_attribute('downstreamImixEnabled')
	@DownstreamImixEnabled.setter
	def DownstreamImixEnabled(self, value):
		self._set_attribute('downstreamImixEnabled', value)

	@property
	def DownstreamImixTemplates(self):
		"""Signifies the downstream IMIX templates.

		Returns:
			str(cisco|imix|ipsec|ipv6|none|quadmodal|standard|tcp|tolly|trimodal)
		"""
		return self._get_attribute('downstreamImixTemplates')
	@DownstreamImixTemplates.setter
	def DownstreamImixTemplates(self, value):
		self._set_attribute('downstreamImixTemplates', value)

	@property
	def DownstreamInitialStepLoadRate(self):
		"""Signifies downstream initial step load rate

		Returns:
			number
		"""
		return self._get_attribute('downstreamInitialStepLoadRate')
	@DownstreamInitialStepLoadRate.setter
	def DownstreamInitialStepLoadRate(self, value):
		self._set_attribute('downstreamInitialStepLoadRate', value)

	@property
	def DownstreamLoadType(self):
		"""Signifies downstream load type

		Returns:
			str(step)
		"""
		return self._get_attribute('downstreamLoadType')
	@DownstreamLoadType.setter
	def DownstreamLoadType(self, value):
		self._set_attribute('downstreamLoadType', value)

	@property
	def DownstreamStepLoadUnit(self):
		"""Signifies downstream step load unit.

		Returns:
			str(bpsRate|fpsRate|gbpsRate|gBpsRate|kbpsRate|kBpsRate|mbpsRate|mBpsRate|percentMaxRate)
		"""
		return self._get_attribute('downstreamStepLoadUnit')
	@DownstreamStepLoadUnit.setter
	def DownstreamStepLoadUnit(self, value):
		self._set_attribute('downstreamStepLoadUnit', value)

	@property
	def DownstreamStepStepLoadRate(self):
		"""Signifies downstream step load rate

		Returns:
			str
		"""
		return self._get_attribute('downstreamStepStepLoadRate')
	@DownstreamStepStepLoadRate.setter
	def DownstreamStepStepLoadRate(self, value):
		self._set_attribute('downstreamStepStepLoadRate', value)

	@property
	def DownstreamStepTolerance(self):
		"""Signifies downstream step tolerance

		Returns:
			number
		"""
		return self._get_attribute('downstreamStepTolerance')
	@DownstreamStepTolerance.setter
	def DownstreamStepTolerance(self, value):
		self._set_attribute('downstreamStepTolerance', value)

	@property
	def Duration(self):
		"""The duration of the test in hours, minutes, or seconds, which is used to calculate.

		Returns:
			number
		"""
		return self._get_attribute('duration')
	@Duration.setter
	def Duration(self, value):
		self._set_attribute('duration', value)

	@property
	def EnableDataIntegrity(self):
		"""Allows to do a data integrity check.

		Returns:
			bool
		"""
		return self._get_attribute('enableDataIntegrity')
	@EnableDataIntegrity.setter
	def EnableDataIntegrity(self, value):
		self._set_attribute('enableDataIntegrity', value)

	@property
	def EnableLayer1Rate(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enableLayer1Rate')
	@EnableLayer1Rate.setter
	def EnableLayer1Rate(self, value):
		self._set_attribute('enableLayer1Rate', value)

	@property
	def EnableMinFrameSize(self):
		"""If true, allows to set minimum frame size.

		Returns:
			bool
		"""
		return self._get_attribute('enableMinFrameSize')
	@EnableMinFrameSize.setter
	def EnableMinFrameSize(self, value):
		self._set_attribute('enableMinFrameSize', value)

	@property
	def ForceRegenerate(self):
		"""Initiates a forced regeneration.

		Returns:
			bool
		"""
		return self._get_attribute('forceRegenerate')
	@ForceRegenerate.setter
	def ForceRegenerate(self, value):
		self._set_attribute('forceRegenerate', value)

	@property
	def FramesPerBurstGap(self):
		"""Specifies the per burst gap.

		Returns:
			number
		"""
		return self._get_attribute('framesPerBurstGap')
	@FramesPerBurstGap.setter
	def FramesPerBurstGap(self, value):
		self._set_attribute('framesPerBurstGap', value)

	@property
	def Gap(self):
		"""The inter burst gap.

		Returns:
			number
		"""
		return self._get_attribute('gap')
	@Gap.setter
	def Gap(self, value):
		self._set_attribute('gap', value)

	@property
	def GenerateTrackingOptionAggregationFiles(self):
		"""Generates tracking option on aggregation files.

		Returns:
			bool
		"""
		return self._get_attribute('generateTrackingOptionAggregationFiles')
	@GenerateTrackingOptionAggregationFiles.setter
	def GenerateTrackingOptionAggregationFiles(self, value):
		self._set_attribute('generateTrackingOptionAggregationFiles', value)

	@property
	def GranularityLabel(self):
		"""Signifies the granulity label

		Returns:
			str
		"""
		return self._get_attribute('granularityLabel')
	@GranularityLabel.setter
	def GranularityLabel(self, value):
		self._set_attribute('granularityLabel', value)

	@property
	def ImixTrafficType(self):
		"""Signifies the traffic type for IMIX

		Returns:
			str
		"""
		return self._get_attribute('imixTrafficType')
	@ImixTrafficType.setter
	def ImixTrafficType(self, value):
		self._set_attribute('imixTrafficType', value)

	@property
	def InitialRateLabel(self):
		"""Signifies the initial rate label

		Returns:
			str
		"""
		return self._get_attribute('initialRateLabel')
	@InitialRateLabel.setter
	def InitialRateLabel(self, value):
		self._set_attribute('initialRateLabel', value)

	@property
	def LatencyBins(self):
		"""DEPRECATED Sets the latency bins statistics.

		Returns:
			str
		"""
		return self._get_attribute('latencyBins')
	@LatencyBins.setter
	def LatencyBins(self, value):
		self._set_attribute('latencyBins', value)

	@property
	def LatencyBinsEnabled(self):
		"""DEPRECATED Enables the latency bins statistics.

		Returns:
			bool
		"""
		return self._get_attribute('latencyBinsEnabled')
	@LatencyBinsEnabled.setter
	def LatencyBinsEnabled(self, value):
		self._set_attribute('latencyBinsEnabled', value)

	@property
	def LatencyType(self):
		"""DEPRECATED The latency type, either Cut Through or Store and Forward.

		Returns:
			str(cutThrough|storeForward)
		"""
		return self._get_attribute('latencyType')
	@LatencyType.setter
	def LatencyType(self, value):
		self._set_attribute('latencyType', value)

	@property
	def LoadType(self):
		"""DEPRECATED The latency type, either Cut Through or Store and Forward.

		Returns:
			str(step)
		"""
		return self._get_attribute('loadType')
	@LoadType.setter
	def LoadType(self, value):
		self._set_attribute('loadType', value)

	@property
	def LoadUnitLabel(self):
		"""DEPRECATED Signifies the load unit label

		Returns:
			str
		"""
		return self._get_attribute('loadUnitLabel')
	@LoadUnitLabel.setter
	def LoadUnitLabel(self, value):
		self._set_attribute('loadUnitLabel', value)

	@property
	def MapType(self):
		"""DEPRECATED The map type.

		Returns:
			str
		"""
		return self._get_attribute('mapType')
	@MapType.setter
	def MapType(self, value):
		self._set_attribute('mapType', value)

	@property
	def NumFrames(self):
		"""DEPRECATED Number of frames.

		Returns:
			number
		"""
		return self._get_attribute('numFrames')
	@NumFrames.setter
	def NumFrames(self, value):
		self._set_attribute('numFrames', value)

	@property
	def Numtrials(self):
		"""DEPRECATED Number of trials.

		Returns:
			number
		"""
		return self._get_attribute('numtrials')
	@Numtrials.setter
	def Numtrials(self, value):
		self._set_attribute('numtrials', value)

	@property
	def PortDelayEnabled(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('portDelayEnabled')
	@PortDelayEnabled.setter
	def PortDelayEnabled(self, value):
		self._set_attribute('portDelayEnabled', value)

	@property
	def PortDelayUnit(self):
		"""DEPRECATED Sets the port delay unit in which it will be measured.

		Returns:
			str(bytes|nanoseconds)
		"""
		return self._get_attribute('portDelayUnit')
	@PortDelayUnit.setter
	def PortDelayUnit(self, value):
		self._set_attribute('portDelayUnit', value)

	@property
	def PortDelayValue(self):
		"""DEPRECATED Sets the port delay value

		Returns:
			number
		"""
		return self._get_attribute('portDelayValue')
	@PortDelayValue.setter
	def PortDelayValue(self, value):
		self._set_attribute('portDelayValue', value)

	@property
	def ProtocolItem(self):
		"""DEPRECATED Protocol Items

		Returns:
			list(str[None|/api/v1/sessions/1/ixnetwork/vport|/api/v1/sessions/1/ixnetwork/vport?deepchild=lan])
		"""
		return self._get_attribute('protocolItem')
	@ProtocolItem.setter
	def ProtocolItem(self, value):
		self._set_attribute('protocolItem', value)

	@property
	def ReportSequenceError(self):
		"""DEPRECATED Specifies to include the types of sequence errors in the results, such as Small.

		Returns:
			bool
		"""
		return self._get_attribute('reportSequenceError')
	@ReportSequenceError.setter
	def ReportSequenceError(self, value):
		self._set_attribute('reportSequenceError', value)

	@property
	def ReportTputRateUnit(self):
		"""DEPRECATED The throughput rate unit.

		Returns:
			str(gbps|gBps|kbps|kBps|mbps|mBps)
		"""
		return self._get_attribute('reportTputRateUnit')
	@ReportTputRateUnit.setter
	def ReportTputRateUnit(self, value):
		self._set_attribute('reportTputRateUnit', value)

	@property
	def Runmode(self):
		"""DEPRECATED The running mode.

		Returns:
			str(duration|noframes)
		"""
		return self._get_attribute('runmode')
	@Runmode.setter
	def Runmode(self, value):
		self._set_attribute('runmode', value)

	@property
	def StaggeredStart(self):
		"""DEPRECATED Enable a staggered start to traffic transmit.

		Returns:
			bool
		"""
		return self._get_attribute('staggeredStart')
	@StaggeredStart.setter
	def StaggeredStart(self, value):
		self._set_attribute('staggeredStart', value)

	@property
	def SupportedTrafficTypes(self):
		"""DEPRECATED The supported traffic types.

		Returns:
			str
		"""
		return self._get_attribute('supportedTrafficTypes')
	@SupportedTrafficTypes.setter
	def SupportedTrafficTypes(self, value):
		self._set_attribute('supportedTrafficTypes', value)

	@property
	def TestType(self):
		"""DEPRECATED Signifies the test type

		Returns:
			str(downstreamOnly|upstreamDownstream|upstreamOnly)
		"""
		return self._get_attribute('testType')
	@TestType.setter
	def TestType(self, value):
		self._set_attribute('testType', value)

	@property
	def TestTypeTemp(self):
		"""DEPRECATED Signifies the temporary test type

		Returns:
			str(downstreamOnly|upstreamDownstream|upstreamOnly)
		"""
		return self._get_attribute('testTypeTemp')
	@TestTypeTemp.setter
	def TestTypeTemp(self, value):
		self._set_attribute('testTypeTemp', value)

	@property
	def TestTypeTemp2(self):
		"""DEPRECATED Signifies the second termorary version of test type

		Returns:
			str(downstreamOnly|upstreamDownstream|upstreamOnly)
		"""
		return self._get_attribute('testTypeTemp2')
	@TestTypeTemp2.setter
	def TestTypeTemp2(self, value):
		self._set_attribute('testTypeTemp2', value)

	@property
	def TrafficType(self):
		"""DEPRECATED The type of traffic to be transmitted.

		Returns:
			str(burstyLoading|constantLoading)
		"""
		return self._get_attribute('trafficType')
	@TrafficType.setter
	def TrafficType(self, value):
		self._set_attribute('trafficType', value)

	@property
	def TxDelay(self):
		"""DEPRECATED The delay in transmission.

		Returns:
			number
		"""
		return self._get_attribute('txDelay')
	@TxDelay.setter
	def TxDelay(self, value):
		self._set_attribute('txDelay', value)

	@property
	def UpstreamGrain(self):
		"""DEPRECATED The upstream traffic grain type.

		Returns:
			str(coarse|fine)
		"""
		return self._get_attribute('upstreamGrain')
	@UpstreamGrain.setter
	def UpstreamGrain(self, value):
		self._set_attribute('upstreamGrain', value)

	@property
	def UpstreamImixAdd(self):
		"""DEPRECATED Adds IMIX upstream.

		Returns:
			str
		"""
		return self._get_attribute('upstreamImixAdd')
	@UpstreamImixAdd.setter
	def UpstreamImixAdd(self, value):
		self._set_attribute('upstreamImixAdd', value)

	@property
	def UpstreamImixData(self):
		"""DEPRECATED Signifies the data of upstream IMIX

		Returns:
			str
		"""
		return self._get_attribute('upstreamImixData')
	@UpstreamImixData.setter
	def UpstreamImixData(self, value):
		self._set_attribute('upstreamImixData', value)

	@property
	def UpstreamImixDataQoS(self):
		"""DEPRECATED Signifies the quality of service for upstream IMIX data

		Returns:
			bool
		"""
		return self._get_attribute('upstreamImixDataQoS')
	@UpstreamImixDataQoS.setter
	def UpstreamImixDataQoS(self, value):
		self._set_attribute('upstreamImixDataQoS', value)

	@property
	def UpstreamImixDelete(self):
		"""DEPRECATED Deletes upstream IMIX

		Returns:
			str
		"""
		return self._get_attribute('upstreamImixDelete')
	@UpstreamImixDelete.setter
	def UpstreamImixDelete(self, value):
		self._set_attribute('upstreamImixDelete', value)

	@property
	def UpstreamImixDistribution(self):
		"""DEPRECATED Signifies the distribution of upstream IMIX

		Returns:
			str(bwpercentage|weight)
		"""
		return self._get_attribute('upstreamImixDistribution')
	@UpstreamImixDistribution.setter
	def UpstreamImixDistribution(self, value):
		self._set_attribute('upstreamImixDistribution', value)

	@property
	def UpstreamImixEnabled(self):
		"""DEPRECATED If true, enables upstream IMIX

		Returns:
			bool
		"""
		return self._get_attribute('upstreamImixEnabled')
	@UpstreamImixEnabled.setter
	def UpstreamImixEnabled(self, value):
		self._set_attribute('upstreamImixEnabled', value)

	@property
	def UpstreamImixTemplates(self):
		"""DEPRECATED Signifies the upstream IMIX templates.

		Returns:
			str(cisco|imix|ipsec|ipv6|none|quadmodal|standard|tcp|tolly|trimodal)
		"""
		return self._get_attribute('upstreamImixTemplates')
	@UpstreamImixTemplates.setter
	def UpstreamImixTemplates(self, value):
		self._set_attribute('upstreamImixTemplates', value)

	@property
	def UpstreamInitialStepLoadRate(self):
		"""DEPRECATED Signifies upstream initial step load rate

		Returns:
			number
		"""
		return self._get_attribute('upstreamInitialStepLoadRate')
	@UpstreamInitialStepLoadRate.setter
	def UpstreamInitialStepLoadRate(self, value):
		self._set_attribute('upstreamInitialStepLoadRate', value)

	@property
	def UpstreamLoadType(self):
		"""DEPRECATED Signifies upstream load type

		Returns:
			str(step)
		"""
		return self._get_attribute('upstreamLoadType')
	@UpstreamLoadType.setter
	def UpstreamLoadType(self, value):
		self._set_attribute('upstreamLoadType', value)

	@property
	def UpstreamStepLoadUnit(self):
		"""DEPRECATED Signifies upstream step load unit.

		Returns:
			str(bpsRate|fpsRate|gbpsRate|gBpsRate|kbpsRate|kBpsRate|mbpsRate|mBpsRate|percentMaxRate)
		"""
		return self._get_attribute('upstreamStepLoadUnit')
	@UpstreamStepLoadUnit.setter
	def UpstreamStepLoadUnit(self, value):
		self._set_attribute('upstreamStepLoadUnit', value)

	@property
	def UpstreamStepStepLoadRate(self):
		"""DEPRECATED Signifies the upstream step load rate

		Returns:
			str
		"""
		return self._get_attribute('upstreamStepStepLoadRate')
	@UpstreamStepStepLoadRate.setter
	def UpstreamStepStepLoadRate(self, value):
		self._set_attribute('upstreamStepStepLoadRate', value)

	@property
	def UpstreamStepTolerance(self):
		"""DEPRECATED Signifies upstream step tolerance value

		Returns:
			number
		"""
		return self._get_attribute('upstreamStepTolerance')
	@UpstreamStepTolerance.setter
	def UpstreamStepTolerance(self, value):
		self._set_attribute('upstreamStepTolerance', value)

	def update(self, BurstSize=None, CalculateJitter=None, CalculateLatency=None, DelayAfterTransmit=None, DownstreamGrain=None, DownstreamImixAdd=None, DownstreamImixData=None, DownstreamImixDataQoS=None, DownstreamImixDelete=None, DownstreamImixDistribution=None, DownstreamImixEnabled=None, DownstreamImixTemplates=None, DownstreamInitialStepLoadRate=None, DownstreamLoadType=None, DownstreamStepLoadUnit=None, DownstreamStepStepLoadRate=None, DownstreamStepTolerance=None, Duration=None, EnableDataIntegrity=None, EnableLayer1Rate=None, EnableMinFrameSize=None, ForceRegenerate=None, FramesPerBurstGap=None, Gap=None, GenerateTrackingOptionAggregationFiles=None, GranularityLabel=None, ImixTrafficType=None, InitialRateLabel=None, LatencyBins=None, LatencyBinsEnabled=None, LatencyType=None, LoadType=None, LoadUnitLabel=None, MapType=None, NumFrames=None, Numtrials=None, PortDelayEnabled=None, PortDelayUnit=None, PortDelayValue=None, ProtocolItem=None, ReportSequenceError=None, ReportTputRateUnit=None, Runmode=None, StaggeredStart=None, SupportedTrafficTypes=None, TestType=None, TestTypeTemp=None, TestTypeTemp2=None, TrafficType=None, TxDelay=None, UpstreamGrain=None, UpstreamImixAdd=None, UpstreamImixData=None, UpstreamImixDataQoS=None, UpstreamImixDelete=None, UpstreamImixDistribution=None, UpstreamImixEnabled=None, UpstreamImixTemplates=None, UpstreamInitialStepLoadRate=None, UpstreamLoadType=None, UpstreamStepLoadUnit=None, UpstreamStepStepLoadRate=None, UpstreamStepTolerance=None):
		"""Updates a child instance of testConfig on the server.

		Args:
			BurstSize (number): The number of packets to send in a burst.
			CalculateJitter (bool): If true, calculates jitter.
			CalculateLatency (bool): If true, calibrates the latency.
			DelayAfterTransmit (number): Specifies the amount of delay after every transmit.
			DownstreamGrain (str(coarse|fine)): The type downstream grain.
			DownstreamImixAdd (str): Adds the IMIX for downstream.
			DownstreamImixData (str): Signifies the downstream IMIX data
			DownstreamImixDataQoS (bool): Signifies the quality of service for downstream IMIX data
			DownstreamImixDelete (str): Deletes the downstream IMIX value
			DownstreamImixDistribution (str(bwpercentage|weight)): It gives details about the down stream Imix distribution.
			DownstreamImixEnabled (bool): If true, enables downstream IMIX
			DownstreamImixTemplates (str(cisco|imix|ipsec|ipv6|none|quadmodal|standard|tcp|tolly|trimodal)): Signifies the downstream IMIX templates.
			DownstreamInitialStepLoadRate (number): Signifies downstream initial step load rate
			DownstreamLoadType (str(step)): Signifies downstream load type
			DownstreamStepLoadUnit (str(bpsRate|fpsRate|gbpsRate|gBpsRate|kbpsRate|kBpsRate|mbpsRate|mBpsRate|percentMaxRate)): Signifies downstream step load unit.
			DownstreamStepStepLoadRate (str): Signifies downstream step load rate
			DownstreamStepTolerance (number): Signifies downstream step tolerance
			Duration (number): The duration of the test in hours, minutes, or seconds, which is used to calculate.
			EnableDataIntegrity (bool): Allows to do a data integrity check.
			EnableLayer1Rate (bool): NOT DEFINED
			EnableMinFrameSize (bool): If true, allows to set minimum frame size.
			ForceRegenerate (bool): Initiates a forced regeneration.
			FramesPerBurstGap (number): Specifies the per burst gap.
			Gap (number): The inter burst gap.
			GenerateTrackingOptionAggregationFiles (bool): Generates tracking option on aggregation files.
			GranularityLabel (str): Signifies the granulity label
			ImixTrafficType (str): Signifies the traffic type for IMIX
			InitialRateLabel (str): Signifies the initial rate label
			LatencyBins (str): Sets the latency bins statistics.
			LatencyBinsEnabled (bool): Enables the latency bins statistics.
			LatencyType (str(cutThrough|storeForward)): The latency type, either Cut Through or Store and Forward.
			LoadType (str(step)): The latency type, either Cut Through or Store and Forward.
			LoadUnitLabel (str): Signifies the load unit label
			MapType (str): The map type.
			NumFrames (number): Number of frames.
			Numtrials (number): Number of trials.
			PortDelayEnabled (bool): NOT DEFINED
			PortDelayUnit (str(bytes|nanoseconds)): Sets the port delay unit in which it will be measured.
			PortDelayValue (number): Sets the port delay value
			ProtocolItem (list(str[None|/api/v1/sessions/1/ixnetwork/vport|/api/v1/sessions/1/ixnetwork/vport?deepchild=lan])): Protocol Items
			ReportSequenceError (bool): Specifies to include the types of sequence errors in the results, such as Small.
			ReportTputRateUnit (str(gbps|gBps|kbps|kBps|mbps|mBps)): The throughput rate unit.
			Runmode (str(duration|noframes)): The running mode.
			StaggeredStart (bool): Enable a staggered start to traffic transmit.
			SupportedTrafficTypes (str): The supported traffic types.
			TestType (str(downstreamOnly|upstreamDownstream|upstreamOnly)): Signifies the test type
			TestTypeTemp (str(downstreamOnly|upstreamDownstream|upstreamOnly)): Signifies the temporary test type
			TestTypeTemp2 (str(downstreamOnly|upstreamDownstream|upstreamOnly)): Signifies the second termorary version of test type
			TrafficType (str(burstyLoading|constantLoading)): The type of traffic to be transmitted.
			TxDelay (number): The delay in transmission.
			UpstreamGrain (str(coarse|fine)): The upstream traffic grain type.
			UpstreamImixAdd (str): Adds IMIX upstream.
			UpstreamImixData (str): Signifies the data of upstream IMIX
			UpstreamImixDataQoS (bool): Signifies the quality of service for upstream IMIX data
			UpstreamImixDelete (str): Deletes upstream IMIX
			UpstreamImixDistribution (str(bwpercentage|weight)): Signifies the distribution of upstream IMIX
			UpstreamImixEnabled (bool): If true, enables upstream IMIX
			UpstreamImixTemplates (str(cisco|imix|ipsec|ipv6|none|quadmodal|standard|tcp|tolly|trimodal)): Signifies the upstream IMIX templates.
			UpstreamInitialStepLoadRate (number): Signifies upstream initial step load rate
			UpstreamLoadType (str(step)): Signifies upstream load type
			UpstreamStepLoadUnit (str(bpsRate|fpsRate|gbpsRate|gBpsRate|kbpsRate|kBpsRate|mbpsRate|mBpsRate|percentMaxRate)): Signifies upstream step load unit.
			UpstreamStepStepLoadRate (str): Signifies the upstream step load rate
			UpstreamStepTolerance (number): Signifies upstream step tolerance value

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def Apply(self):
		"""Executes the apply operation on the server.

		Applies the specified Quick Test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('apply', payload=payload, response_object=None)

	def ApplyAsync(self):
		"""Executes the applyAsync operation on the server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('applyAsync', payload=payload, response_object=None)

	def ApplyAsyncResult(self):
		"""Executes the applyAsyncResult operation on the server.

			Returns:
				bool: 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('applyAsyncResult', payload=payload, response_object=None)

	def ApplyITWizardConfiguration(self):
		"""Executes the applyITWizardConfiguration operation on the server.

		Applies the specified Quick Test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('applyITWizardConfiguration', payload=payload, response_object=None)

	def GenerateReport(self):
		"""Executes the generateReport operation on the server.

		Generate a PDF report for the last succesfull test run.

			Returns:
				str: This method is asynchronous and has no return value.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('generateReport', payload=payload, response_object=None)

	def Run(self, *args, **kwargs):
		"""Executes the run operation on the server.

		Starts the specified Quick Test and waits for its execution to finish.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		run()list

			Returns:
				list(str): This method is synchronous and returns the result of the test.

		run(InputParameters:string)list
			Args:
				args[0] is InputParameters (str): The input arguments of the test.

			Returns:
				list(str): This method is synchronous and returns the result of the test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('run', payload=payload, response_object=None)

	def Start(self, *args, **kwargs):
		"""Executes the start operation on the server.

		Starts the specified Quick Test.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		start()

		start(InputParameters:string)
			Args:
				args[0] is InputParameters (str): The input arguments of the test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('start', payload=payload, response_object=None)

	def Stop(self):
		"""Executes the stop operation on the server.

		Stops the currently running Quick Test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('stop', payload=payload, response_object=None)

	def WaitForTest(self):
		"""Executes the waitForTest operation on the server.

		Waits for the execution of the specified Quick Test to be completed.

			Returns:
				list(str): This method is synchronous and returns the result of the test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('waitForTest', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class TestConfig(Base):
	"""The TestConfig class encapsulates a required testConfig node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the TestConfig property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'testConfig'

	def __init__(self, parent):
		super(TestConfig, self).__init__(parent)

	@property
	def BidirectionalOptionEnabled(self):
		"""If true, allows bidirectional traffic.

		Returns:
			bool
		"""
		return self._get_attribute('bidirectionalOptionEnabled')
	@BidirectionalOptionEnabled.setter
	def BidirectionalOptionEnabled(self, value):
		self._set_attribute('bidirectionalOptionEnabled', value)

	@property
	def BinarySearchType(self):
		"""The binary search type value.

		Returns:
			str(linear|perFlow|perPort)
		"""
		return self._get_attribute('binarySearchType')
	@BinarySearchType.setter
	def BinarySearchType(self, value):
		self._set_attribute('binarySearchType', value)

	@property
	def BurstSize(self):
		"""The number of packets that are sent in a burst.

		Returns:
			number
		"""
		return self._get_attribute('burstSize')
	@BurstSize.setter
	def BurstSize(self, value):
		self._set_attribute('burstSize', value)

	@property
	def CountRandomFrameSize(self):
		"""If true, frame sizes are counted at random.

		Returns:
			number
		"""
		return self._get_attribute('countRandomFrameSize')
	@CountRandomFrameSize.setter
	def CountRandomFrameSize(self, value):
		self._set_attribute('countRandomFrameSize', value)

	@property
	def DelayAfterTransmit(self):
		"""A delay that is inserted after transmit is complete, before it continues with the test.

		Returns:
			number
		"""
		return self._get_attribute('delayAfterTransmit')
	@DelayAfterTransmit.setter
	def DelayAfterTransmit(self, value):
		self._set_attribute('delayAfterTransmit', value)

	@property
	def Duration(self):
		"""The duration of the test in hours, which is used to calculate the number of frames to transmit.

		Returns:
			number
		"""
		return self._get_attribute('duration')
	@Duration.setter
	def Duration(self, value):
		self._set_attribute('duration', value)

	@property
	def EnableAlignmentErr(self):
		"""If true, alignment error is enabled.

		Returns:
			bool
		"""
		return self._get_attribute('enableAlignmentErr')
	@EnableAlignmentErr.setter
	def EnableAlignmentErr(self, value):
		self._set_attribute('enableAlignmentErr', value)

	@property
	def EnableBadCrcErr(self):
		"""If true, BadCrc error is enabled.

		Returns:
			bool
		"""
		return self._get_attribute('enableBadCrcErr')
	@EnableBadCrcErr.setter
	def EnableBadCrcErr(self, value):
		self._set_attribute('enableBadCrcErr', value)

	@property
	def EnableDribbleErr(self):
		"""If true, dribble error. is enabled.

		Returns:
			bool
		"""
		return self._get_attribute('enableDribbleErr')
	@EnableDribbleErr.setter
	def EnableDribbleErr(self, value):
		self._set_attribute('enableDribbleErr', value)

	@property
	def EnableFragmentErr(self):
		"""If true, fragment error is enabled.

		Returns:
			bool
		"""
		return self._get_attribute('enableFragmentErr')
	@EnableFragmentErr.setter
	def EnableFragmentErr(self, value):
		self._set_attribute('enableFragmentErr', value)

	@property
	def EnableMinFrameSize(self):
		"""If true, IxNetwork will allow the stream to use smaller packet sizes. In the case of IPv4 and Ethernet, 64 bytes will be allowed. This is achieved by reducing the size of the instrumentation tag, which will be identified by receiving ports.

		Returns:
			bool
		"""
		return self._get_attribute('enableMinFrameSize')
	@EnableMinFrameSize.setter
	def EnableMinFrameSize(self, value):
		self._set_attribute('enableMinFrameSize', value)

	@property
	def EnableOversizeErr(self):
		"""If true, oversize error is enabled.

		Returns:
			bool
		"""
		return self._get_attribute('enableOversizeErr')
	@EnableOversizeErr.setter
	def EnableOversizeErr(self, value):
		self._set_attribute('enableOversizeErr', value)

	@property
	def EnableUndersizeErr(self):
		"""If true, oversize error is enabled.

		Returns:
			bool
		"""
		return self._get_attribute('enableUndersizeErr')
	@EnableUndersizeErr.setter
	def EnableUndersizeErr(self, value):
		self._set_attribute('enableUndersizeErr', value)

	@property
	def EnforceBidirectional(self):
		"""If true, uses bidirectional traffic mapping.

		Returns:
			bool
		"""
		return self._get_attribute('enforceBidirectional')
	@EnforceBidirectional.setter
	def EnforceBidirectional(self, value):
		self._set_attribute('enforceBidirectional', value)

	@property
	def ForceRegenerate(self):
		"""Initiates a forced regeneration.

		Returns:
			bool
		"""
		return self._get_attribute('forceRegenerate')
	@ForceRegenerate.setter
	def ForceRegenerate(self, value):
		self._set_attribute('forceRegenerate', value)

	@property
	def FragmentFramesizeList(self):
		"""The list of fragmented framesize.

		Returns:
			str
		"""
		return self._get_attribute('fragmentFramesizeList')
	@FragmentFramesizeList.setter
	def FragmentFramesizeList(self, value):
		self._set_attribute('fragmentFramesizeList', value)

	@property
	def FrameSizeMode(self):
		"""This attribute is the frame size mode for the Quad Gaussian.

		Returns:
			str(custom|increment|random)
		"""
		return self._get_attribute('frameSizeMode')
	@FrameSizeMode.setter
	def FrameSizeMode(self, value):
		self._set_attribute('frameSizeMode', value)

	@property
	def FramesizeList(self):
		"""List containing the frame sizes used in the test.

		Returns:
			list(str)
		"""
		return self._get_attribute('framesizeList')
	@FramesizeList.setter
	def FramesizeList(self, value):
		self._set_attribute('framesizeList', value)

	@property
	def LoadRatePercent(self):
		"""The percent value of Load Rate.

		Returns:
			number
		"""
		return self._get_attribute('loadRatePercent')
	@LoadRatePercent.setter
	def LoadRatePercent(self, value):
		self._set_attribute('loadRatePercent', value)

	@property
	def LoadType(self):
		"""The type of the payload setting.

		Returns:
			str(binary|combo|custom|fixed|increment|quickSearch|random|step|unchanged)
		"""
		return self._get_attribute('loadType')
	@LoadType.setter
	def LoadType(self, value):
		self._set_attribute('loadType', value)

	@property
	def MapType(self):
		"""The POS traffic map type.

		Returns:
			str
		"""
		return self._get_attribute('mapType')
	@MapType.setter
	def MapType(self, value):
		self._set_attribute('mapType', value)

	@property
	def MaxIncrementFrameSize(self):
		"""The integer that states the maximum amount to which the frame size can be incremented.

		Returns:
			number
		"""
		return self._get_attribute('maxIncrementFrameSize')
	@MaxIncrementFrameSize.setter
	def MaxIncrementFrameSize(self, value):
		self._set_attribute('maxIncrementFrameSize', value)

	@property
	def MaxRandomFrameSize(self):
		"""The integer that states the maximum random amount to which the frame size can be incremented.

		Returns:
			number
		"""
		return self._get_attribute('maxRandomFrameSize')
	@MaxRandomFrameSize.setter
	def MaxRandomFrameSize(self, value):
		self._set_attribute('maxRandomFrameSize', value)

	@property
	def MinIncrementFrameSize(self):
		"""The integer that states the minimum amount to which the frame size can be incremented.

		Returns:
			number
		"""
		return self._get_attribute('minIncrementFrameSize')
	@MinIncrementFrameSize.setter
	def MinIncrementFrameSize(self, value):
		self._set_attribute('minIncrementFrameSize', value)

	@property
	def MinRandomFrameSize(self):
		"""The integer that states the minimum random amount to which the frame size can be incremented.

		Returns:
			number
		"""
		return self._get_attribute('minRandomFrameSize')
	@MinRandomFrameSize.setter
	def MinRandomFrameSize(self, value):
		self._set_attribute('minRandomFrameSize', value)

	@property
	def Numtrials(self):
		"""Defines how many times each frame size will be tested.

		Returns:
			number
		"""
		return self._get_attribute('numtrials')
	@Numtrials.setter
	def Numtrials(self, value):
		self._set_attribute('numtrials', value)

	@property
	def OversizeFramesizeList(self):
		"""The list of oversized framesize.

		Returns:
			str
		"""
		return self._get_attribute('oversizeFramesizeList')
	@OversizeFramesizeList.setter
	def OversizeFramesizeList(self, value):
		self._set_attribute('oversizeFramesizeList', value)

	@property
	def PassFailNote(self):
		"""The note that indicates whether the test has cleared the pass/fail criterion or not.

		Returns:
			str
		"""
		return self._get_attribute('passFailNote')
	@PassFailNote.setter
	def PassFailNote(self, value):
		self._set_attribute('passFailNote', value)

	@property
	def PortDelayEnabled(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('portDelayEnabled')
	@PortDelayEnabled.setter
	def PortDelayEnabled(self, value):
		self._set_attribute('portDelayEnabled', value)

	@property
	def PortDelayUnit(self):
		"""Sets the port delay unit in which it will be measured

		Returns:
			str(bytes|nanoseconds)
		"""
		return self._get_attribute('portDelayUnit')
	@PortDelayUnit.setter
	def PortDelayUnit(self, value):
		self._set_attribute('portDelayUnit', value)

	@property
	def PortDelayValue(self):
		"""Sets the port delay value

		Returns:
			number
		"""
		return self._get_attribute('portDelayValue')
	@PortDelayValue.setter
	def PortDelayValue(self, value):
		self._set_attribute('portDelayValue', value)

	@property
	def ProtocolItem(self):
		"""Protocol Items

		Returns:
			list(str[None|/api/v1/sessions/1/ixnetwork/vport|/api/v1/sessions/1/ixnetwork/vport?deepchild=lan])
		"""
		return self._get_attribute('protocolItem')
	@ProtocolItem.setter
	def ProtocolItem(self, value):
		self._set_attribute('protocolItem', value)

	@property
	def SendFullyMeshed(self):
		"""Sending fully meshed traffic.

		Returns:
			bool
		"""
		return self._get_attribute('sendFullyMeshed')
	@SendFullyMeshed.setter
	def SendFullyMeshed(self, value):
		self._set_attribute('sendFullyMeshed', value)

	@property
	def StepIncrementFrameSize(self):
		"""The step to increment the frame size.

		Returns:
			number
		"""
		return self._get_attribute('stepIncrementFrameSize')
	@StepIncrementFrameSize.setter
	def StepIncrementFrameSize(self, value):
		self._set_attribute('stepIncrementFrameSize', value)

	@property
	def SupportedTrafficTypes(self):
		"""The traffic types supported.

		Returns:
			str
		"""
		return self._get_attribute('supportedTrafficTypes')
	@SupportedTrafficTypes.setter
	def SupportedTrafficTypes(self, value):
		self._set_attribute('supportedTrafficTypes', value)

	@property
	def TrafficType(self):
		"""The test based on the traffic type.

		Returns:
			str(burstyLoading|constantLoading)
		"""
		return self._get_attribute('trafficType')
	@TrafficType.setter
	def TrafficType(self, value):
		self._set_attribute('trafficType', value)

	@property
	def TxDelay(self):
		"""The minimum delay between successive LLDP packets. The default value is 2, the minimum is 1, and the maximum is 8192. Note that Tx Delay must be lower than txInterval.

		Returns:
			number
		"""
		return self._get_attribute('txDelay')
	@TxDelay.setter
	def TxDelay(self, value):
		self._set_attribute('txDelay', value)

	@property
	def UndersizeFramesizeList(self):
		"""The list of undersized framesize.

		Returns:
			str
		"""
		return self._get_attribute('undersizeFramesizeList')
	@UndersizeFramesizeList.setter
	def UndersizeFramesizeList(self, value):
		self._set_attribute('undersizeFramesizeList', value)

	def update(self, BidirectionalOptionEnabled=None, BinarySearchType=None, BurstSize=None, CountRandomFrameSize=None, DelayAfterTransmit=None, Duration=None, EnableAlignmentErr=None, EnableBadCrcErr=None, EnableDribbleErr=None, EnableFragmentErr=None, EnableMinFrameSize=None, EnableOversizeErr=None, EnableUndersizeErr=None, EnforceBidirectional=None, ForceRegenerate=None, FragmentFramesizeList=None, FrameSizeMode=None, FramesizeList=None, LoadRatePercent=None, LoadType=None, MapType=None, MaxIncrementFrameSize=None, MaxRandomFrameSize=None, MinIncrementFrameSize=None, MinRandomFrameSize=None, Numtrials=None, OversizeFramesizeList=None, PassFailNote=None, PortDelayEnabled=None, PortDelayUnit=None, PortDelayValue=None, ProtocolItem=None, SendFullyMeshed=None, StepIncrementFrameSize=None, SupportedTrafficTypes=None, TrafficType=None, TxDelay=None, UndersizeFramesizeList=None):
		"""Updates a child instance of testConfig on the server.

		Args:
			BidirectionalOptionEnabled (bool): If true, allows bidirectional traffic.
			BinarySearchType (str(linear|perFlow|perPort)): The binary search type value.
			BurstSize (number): The number of packets that are sent in a burst.
			CountRandomFrameSize (number): If true, frame sizes are counted at random.
			DelayAfterTransmit (number): A delay that is inserted after transmit is complete, before it continues with the test.
			Duration (number): The duration of the test in hours, which is used to calculate the number of frames to transmit.
			EnableAlignmentErr (bool): If true, alignment error is enabled.
			EnableBadCrcErr (bool): If true, BadCrc error is enabled.
			EnableDribbleErr (bool): If true, dribble error. is enabled.
			EnableFragmentErr (bool): If true, fragment error is enabled.
			EnableMinFrameSize (bool): If true, IxNetwork will allow the stream to use smaller packet sizes. In the case of IPv4 and Ethernet, 64 bytes will be allowed. This is achieved by reducing the size of the instrumentation tag, which will be identified by receiving ports.
			EnableOversizeErr (bool): If true, oversize error is enabled.
			EnableUndersizeErr (bool): If true, oversize error is enabled.
			EnforceBidirectional (bool): If true, uses bidirectional traffic mapping.
			ForceRegenerate (bool): Initiates a forced regeneration.
			FragmentFramesizeList (str): The list of fragmented framesize.
			FrameSizeMode (str(custom|increment|random)): This attribute is the frame size mode for the Quad Gaussian.
			FramesizeList (list(str)): List containing the frame sizes used in the test.
			LoadRatePercent (number): The percent value of Load Rate.
			LoadType (str(binary|combo|custom|fixed|increment|quickSearch|random|step|unchanged)): The type of the payload setting.
			MapType (str): The POS traffic map type.
			MaxIncrementFrameSize (number): The integer that states the maximum amount to which the frame size can be incremented.
			MaxRandomFrameSize (number): The integer that states the maximum random amount to which the frame size can be incremented.
			MinIncrementFrameSize (number): The integer that states the minimum amount to which the frame size can be incremented.
			MinRandomFrameSize (number): The integer that states the minimum random amount to which the frame size can be incremented.
			Numtrials (number): Defines how many times each frame size will be tested.
			OversizeFramesizeList (str): The list of oversized framesize.
			PassFailNote (str): The note that indicates whether the test has cleared the pass/fail criterion or not.
			PortDelayEnabled (bool): NOT DEFINED
			PortDelayUnit (str(bytes|nanoseconds)): Sets the port delay unit in which it will be measured
			PortDelayValue (number): Sets the port delay value
			ProtocolItem (list(str[None|/api/v1/sessions/1/ixnetwork/vport|/api/v1/sessions/1/ixnetwork/vport?deepchild=lan])): Protocol Items
			SendFullyMeshed (bool): Sending fully meshed traffic.
			StepIncrementFrameSize (number): The step to increment the frame size.
			SupportedTrafficTypes (str): The traffic types supported.
			TrafficType (str(burstyLoading|constantLoading)): The test based on the traffic type.
			TxDelay (number): The minimum delay between successive LLDP packets. The default value is 2, the minimum is 1, and the maximum is 8192. Note that Tx Delay must be lower than txInterval.
			UndersizeFramesizeList (str): The list of undersized framesize.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def Apply(self):
		"""Executes the apply operation on the server.

		Applies the specified Quick Test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('apply', payload=payload, response_object=None)

	def ApplyAsync(self):
		"""Executes the applyAsync operation on the server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('applyAsync', payload=payload, response_object=None)

	def ApplyAsyncResult(self):
		"""Executes the applyAsyncResult operation on the server.

			Returns:
				bool: 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('applyAsyncResult', payload=payload, response_object=None)

	def ApplyITWizardConfiguration(self):
		"""Executes the applyITWizardConfiguration operation on the server.

		Applies the specified Quick Test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('applyITWizardConfiguration', payload=payload, response_object=None)

	def GenerateReport(self):
		"""Executes the generateReport operation on the server.

		Generate a PDF report for the last succesfull test run.

			Returns:
				str: This method is asynchronous and has no return value.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('generateReport', payload=payload, response_object=None)

	def Run(self, *args, **kwargs):
		"""Executes the run operation on the server.

		Starts the specified Quick Test and waits for its execution to finish.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		run()list

			Returns:
				list(str): This method is synchronous and returns the result of the test.

		run(InputParameters:string)list
			Args:
				args[0] is InputParameters (str): The input arguments of the test.

			Returns:
				list(str): This method is synchronous and returns the result of the test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('run', payload=payload, response_object=None)

	def Start(self, *args, **kwargs):
		"""Executes the start operation on the server.

		Starts the specified Quick Test.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		start()

		start(InputParameters:string)
			Args:
				args[0] is InputParameters (str): The input arguments of the test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('start', payload=payload, response_object=None)

	def Stop(self):
		"""Executes the stop operation on the server.

		Stops the currently running Quick Test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('stop', payload=payload, response_object=None)

	def WaitForTest(self):
		"""Executes the waitForTest operation on the server.

		Waits for the execution of the specified Quick Test to be completed.

			Returns:
				list(str): This method is synchronous and returns the result of the test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('waitForTest', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class TrillNodeMacRanges(Base):
	"""The TrillNodeMacRanges class encapsulates a user managed trillNodeMacRanges node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the TrillNodeMacRanges property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'trillNodeMacRanges'

	def __init__(self, parent):
		super(TrillNodeMacRanges, self).__init__(parent)

	@property
	def Count(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('count')
	@Count.setter
	def Count(self, value):
		self._set_attribute('count', value)

	@property
	def EnableMacRanges(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enableMacRanges')
	@EnableMacRanges.setter
	def EnableMacRanges(self, value):
		self._set_attribute('enableMacRanges', value)

	@property
	def InterNodeMacStep(self):
		"""NOT DEFINED

		Returns:
			str
		"""
		return self._get_attribute('interNodeMacStep')
	@InterNodeMacStep.setter
	def InterNodeMacStep(self, value):
		self._set_attribute('interNodeMacStep', value)

	@property
	def StartUnicastMac(self):
		"""NOT DEFINED

		Returns:
			str
		"""
		return self._get_attribute('startUnicastMac')
	@StartUnicastMac.setter
	def StartUnicastMac(self, value):
		self._set_attribute('startUnicastMac', value)

	@property
	def TopologyId(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('topologyId')

	@property
	def UnicastMacStep(self):
		"""NOT DEFINED

		Returns:
			str
		"""
		return self._get_attribute('unicastMacStep')
	@UnicastMacStep.setter
	def UnicastMacStep(self, value):
		self._set_attribute('unicastMacStep', value)

	@property
	def VlanId(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('vlanId')
	@VlanId.setter
	def VlanId(self, value):
		self._set_attribute('vlanId', value)

	def update(self, Count=None, EnableMacRanges=None, InterNodeMacStep=None, StartUnicastMac=None, UnicastMacStep=None, VlanId=None):
		"""Updates a child instance of trillNodeMacRanges on the server.

		Args:
			Count (number): NOT DEFINED
			EnableMacRanges (bool): NOT DEFINED
			InterNodeMacStep (str): NOT DEFINED
			StartUnicastMac (str): NOT DEFINED
			UnicastMacStep (str): NOT DEFINED
			VlanId (number): NOT DEFINED

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, Count=None, EnableMacRanges=None, InterNodeMacStep=None, StartUnicastMac=None, UnicastMacStep=None, VlanId=None):
		"""Adds a new trillNodeMacRanges node on the server and retrieves it in this instance.

		Args:
			Count (number): NOT DEFINED
			EnableMacRanges (bool): NOT DEFINED
			InterNodeMacStep (str): NOT DEFINED
			StartUnicastMac (str): NOT DEFINED
			UnicastMacStep (str): NOT DEFINED
			VlanId (number): NOT DEFINED

		Returns:
			self: This instance with all currently retrieved trillNodeMacRanges data using find and the newly added trillNodeMacRanges data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the trillNodeMacRanges data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, Count=None, EnableMacRanges=None, InterNodeMacStep=None, StartUnicastMac=None, TopologyId=None, UnicastMacStep=None, VlanId=None):
		"""Finds and retrieves trillNodeMacRanges data from the server.

		All named parameters support regex and can be used to selectively retrieve trillNodeMacRanges data from the server.
		By default the find method takes no parameters and will retrieve all trillNodeMacRanges data from the server.

		Args:
			Count (number): NOT DEFINED
			EnableMacRanges (bool): NOT DEFINED
			InterNodeMacStep (str): NOT DEFINED
			StartUnicastMac (str): NOT DEFINED
			TopologyId (number): NOT DEFINED
			UnicastMacStep (str): NOT DEFINED
			VlanId (number): NOT DEFINED

		Returns:
			self: This instance with matching trillNodeMacRanges data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of trillNodeMacRanges data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the trillNodeMacRanges data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class OfChannelLearnedInformation(Base):
	"""The OfChannelLearnedInformation class encapsulates a system managed ofChannelLearnedInformation node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the OfChannelLearnedInformation property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server by using the find method.
	"""

	_SDM_NAME = 'ofChannelLearnedInformation'

	def __init__(self, parent):
		super(OfChannelLearnedInformation, self).__init__(parent)

	@property
	def ControllerAuxiliaryConnectionLearnedInfo(self):
		"""An instance of the ControllerAuxiliaryConnectionLearnedInfo class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.controllerauxiliaryconnectionlearnedinfo.ControllerAuxiliaryConnectionLearnedInfo)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.controllerauxiliaryconnectionlearnedinfo import ControllerAuxiliaryConnectionLearnedInfo
		return ControllerAuxiliaryConnectionLearnedInfo(self)

	@property
	def OfChannelPortsLearnedInformation(self):
		"""An instance of the OfChannelPortsLearnedInformation class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.ofchannelportslearnedinformation.OfChannelPortsLearnedInformation)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.ofchannelportslearnedinformation import OfChannelPortsLearnedInformation
		return OfChannelPortsLearnedInformation(self)

	@property
	def ActionsSupported(self):
		"""Signifies the types of actions supported by the switch.

		Returns:
			str
		"""
		return self._get_attribute('actionsSupported')

	@property
	def Capabilities(self):
		"""Signifies the capabilities of the switch.

		Returns:
			str
		"""
		return self._get_attribute('capabilities')

	@property
	def DataPathId(self):
		"""Indicates the datapath ID of the OpenFlow switch.

		Returns:
			str
		"""
		return self._get_attribute('dataPathId')

	@property
	def DataPathIdAsHex(self):
		"""Indicates the datapath ID of the OpenFlow switch in hexadecimal format.

		Returns:
			str
		"""
		return self._get_attribute('dataPathIdAsHex')

	@property
	def FlowRate(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('flowRate')

	@property
	def GenerationId(self):
		"""The generation ID number.

		Returns:
			str
		"""
		return self._get_attribute('generationId')

	@property
	def LastErrorCode(self):
		"""Signifies the error code of the last error received.

		Returns:
			str
		"""
		return self._get_attribute('lastErrorCode')

	@property
	def LastErrorType(self):
		"""Signifies the type of the last error received.

		Returns:
			str
		"""
		return self._get_attribute('lastErrorType')

	@property
	def LocalIp(self):
		"""Signifies the local IP address of the selected interface.

		Returns:
			str
		"""
		return self._get_attribute('localIp')

	@property
	def LocalPortNumber(self):
		"""Signifies the local port number identifier.

		Returns:
			number
		"""
		return self._get_attribute('localPortNumber')

	@property
	def MaxBufferSize(self):
		"""Signifies the maximum configurable buffer size.

		Returns:
			number
		"""
		return self._get_attribute('maxBufferSize')

	@property
	def NegotiatedVersion(self):
		"""Version of the protocol that has been negotiated between OpenFLow Controller and Switch.

		Returns:
			number
		"""
		return self._get_attribute('negotiatedVersion')

	@property
	def NumberOfErrorsReceived(self):
		"""Signifies the total number of errors received from the emulation start time.

		Returns:
			number
		"""
		return self._get_attribute('numberOfErrorsReceived')

	@property
	def NumberOfPorts(self):
		"""Signifies the number of ports used.

		Returns:
			number
		"""
		return self._get_attribute('numberOfPorts')

	@property
	def NumberOfTables(self):
		"""Signifies the number of tables supported.

		Returns:
			number
		"""
		return self._get_attribute('numberOfTables')

	@property
	def RemoteIp(self):
		"""Signifies the Remote IP address of the selected interface.

		Returns:
			str
		"""
		return self._get_attribute('remoteIp')

	@property
	def RemotePortNumber(self):
		"""Signifies the remote port number identifier.

		Returns:
			number
		"""
		return self._get_attribute('remotePortNumber')

	@property
	def ReplyState(self):
		"""Signifies the reply state of the OF Channel.

		Returns:
			str
		"""
		return self._get_attribute('replyState')

	@property
	def Role(self):
		"""NOT DEFINED

		Returns:
			str
		"""
		return self._get_attribute('role')

	@property
	def SessionType(self):
		"""Signifies the type of OpenFlow session supported by the switch.

		Returns:
			str
		"""
		return self._get_attribute('sessionType')

	def find(self, ActionsSupported=None, Capabilities=None, DataPathId=None, DataPathIdAsHex=None, FlowRate=None, GenerationId=None, LastErrorCode=None, LastErrorType=None, LocalIp=None, LocalPortNumber=None, MaxBufferSize=None, NegotiatedVersion=None, NumberOfErrorsReceived=None, NumberOfPorts=None, NumberOfTables=None, RemoteIp=None, RemotePortNumber=None, ReplyState=None, Role=None, SessionType=None):
		"""Finds and retrieves ofChannelLearnedInformation data from the server.

		All named parameters support regex and can be used to selectively retrieve ofChannelLearnedInformation data from the server.
		By default the find method takes no parameters and will retrieve all ofChannelLearnedInformation data from the server.

		Args:
			ActionsSupported (str): Signifies the types of actions supported by the switch.
			Capabilities (str): Signifies the capabilities of the switch.
			DataPathId (str): Indicates the datapath ID of the OpenFlow switch.
			DataPathIdAsHex (str): Indicates the datapath ID of the OpenFlow switch in hexadecimal format.
			FlowRate (number): NOT DEFINED
			GenerationId (str): The generation ID number.
			LastErrorCode (str): Signifies the error code of the last error received.
			LastErrorType (str): Signifies the type of the last error received.
			LocalIp (str): Signifies the local IP address of the selected interface.
			LocalPortNumber (number): Signifies the local port number identifier.
			MaxBufferSize (number): Signifies the maximum configurable buffer size.
			NegotiatedVersion (number): Version of the protocol that has been negotiated between OpenFLow Controller and Switch.
			NumberOfErrorsReceived (number): Signifies the total number of errors received from the emulation start time.
			NumberOfPorts (number): Signifies the number of ports used.
			NumberOfTables (number): Signifies the number of tables supported.
			RemoteIp (str): Signifies the Remote IP address of the selected interface.
			RemotePortNumber (number): Signifies the remote port number identifier.
			ReplyState (str): Signifies the reply state of the OF Channel.
			Role (str): NOT DEFINED
			SessionType (str): Signifies the type of OpenFlow session supported by the switch.

		Returns:
			self: This instance with matching ofChannelLearnedInformation data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of ofChannelLearnedInformation data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the ofChannelLearnedInformation data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)

	def AddRecordForTrigger(self):
		"""Executes the addRecordForTrigger operation on the server.

		This describes the record added for trigger settings.

			Returns:
				bool: NOT DEFINED

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('addRecordForTrigger', payload=payload, response_object=None)

	def ConfigureOfChannel(self):
		"""Executes the configureOfChannel operation on the server.

		It is a command that will configure controller OF channel from controller OF channel learned information.

			Returns:
				bool: NOT DEFINED

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('configureOfChannel', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class GroupCapabilities(Base):
	"""The GroupCapabilities class encapsulates a required groupCapabilities node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the GroupCapabilities property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'groupCapabilities'

	def __init__(self, parent):
		super(GroupCapabilities, self).__init__(parent)

	@property
	def Chaining(self):
		"""Chaining groups.

		Returns:
			bool
		"""
		return self._get_attribute('chaining')
	@Chaining.setter
	def Chaining(self, value):
		self._set_attribute('chaining', value)

	@property
	def ChainingChecks(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('chainingChecks')
	@ChainingChecks.setter
	def ChainingChecks(self, value):
		self._set_attribute('chainingChecks', value)

	@property
	def SelectLiveness(self):
		"""Liveness for select groups.

		Returns:
			bool
		"""
		return self._get_attribute('selectLiveness')
	@SelectLiveness.setter
	def SelectLiveness(self, value):
		self._set_attribute('selectLiveness', value)

	@property
	def SelectWeight(self):
		"""Weight for select groups.

		Returns:
			bool
		"""
		return self._get_attribute('selectWeight')
	@SelectWeight.setter
	def SelectWeight(self, value):
		self._set_attribute('selectWeight', value)

	def update(self, Chaining=None, ChainingChecks=None, SelectLiveness=None, SelectWeight=None):
		"""Updates a child instance of groupCapabilities on the server.

		Args:
			Chaining (bool): Chaining groups.
			ChainingChecks (bool): NOT DEFINED
			SelectLiveness (bool): Liveness for select groups.
			SelectWeight (bool): Weight for select groups.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class PimV4Interface(Base):
	"""The PimV4Interface class encapsulates a user managed pimV4Interface node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the PimV4Interface property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'pimV4Interface'

	def __init__(self, parent):
		super(PimV4Interface, self).__init__(parent)

	@property
	def LearnedInfo(self):
		"""An instance of the LearnedInfo class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.learnedinfo.learnedinfo.LearnedInfo)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.learnedinfo.learnedinfo import LearnedInfo
		return LearnedInfo(self)

	@property
	def PimV4CandidateRPsList(self):
		"""An instance of the PimV4CandidateRPsList class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.pimv4candidaterpslist.PimV4CandidateRPsList)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.pimv4candidaterpslist import PimV4CandidateRPsList
		return PimV4CandidateRPsList(self)._select()

	@property
	def PimV4JoinPruneList(self):
		"""An instance of the PimV4JoinPruneList class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.pimv4joinprunelist.PimV4JoinPruneList)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.pimv4joinprunelist import PimV4JoinPruneList
		return PimV4JoinPruneList(self)._select()

	@property
	def PimV4SourcesList(self):
		"""An instance of the PimV4SourcesList class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.pimv4sourceslist.PimV4SourcesList)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.pimv4sourceslist import PimV4SourcesList
		return PimV4SourcesList(self)._select()

	@property
	def Tag(self):
		"""An instance of the Tag class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.tag.Tag)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.tag import Tag
		return Tag(self)

	@property
	def Active(self):
		"""Activate/Deactivate Configuration

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('active')

	@property
	def AutoPickNeighbor(self):
		"""If selected, the time-saving Auto Pick feature is enabled-and the Upstream Neighbor field is not available for use. The Upstream Neighbor address used in the Join/Prune message is determined automatically from received Hello messages. The first time a Hello message is received-containing a Source (link-local) address that does not belong to this interface, that source address will be used as the Upstream Neighbor address. If not selected, the user can type in the link-local address in the Upstream Neighbor IP field (see Neighbor field below)-to be used for the upstream neighbor address field in the Join/Prune message.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('autoPickNeighbor')

	@property
	def BootstrapHashMaskLength(self):
		"""Hash Mask Length of the Bootstrap Router (BSR) that is set with the same name in all Bootstrap Messages sent by this BSR.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('bootstrapHashMaskLength')

	@property
	def BootstrapInterval(self):
		"""The time interval (in seconds) between two consecutive bootstrap messages sent by the BSR.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('bootstrapInterval')

	@property
	def BootstrapPriority(self):
		"""Priority of the Bootstrap Router (BSR) that is set with the same name in all Bootstrap Messages sent by this BSR.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('bootstrapPriority')

	@property
	def BootstrapTimeout(self):
		"""Amount of time (in seconds) of not receiving any Bootstrap Messages, after which, the BSR if candidate at that point of time will decide that the currently elected BSR has gone down and will restart BSR election procedure.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('bootstrapTimeout')

	@property
	def ConnectedVia(self):
		"""DEPRECATED List of layers this layer used to connect to the wire

		Returns:
			list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])
		"""
		return self._get_attribute('connectedVia')
	@ConnectedVia.setter
	def ConnectedVia(self, value):
		self._set_attribute('connectedVia', value)

	@property
	def Count(self):
		"""DEPRECATED Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group

		Returns:
			number
		"""
		return self._get_attribute('count')

	@property
	def CrpRanges(self):
		"""DEPRECATED Number of C-RP Ranges

		Returns:
			number
		"""
		return self._get_attribute('crpRanges')
	@CrpRanges.setter
	def CrpRanges(self, value):
		self._set_attribute('crpRanges', value)

	@property
	def DescriptiveName(self):
		"""DEPRECATED Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context

		Returns:
			str
		"""
		return self._get_attribute('descriptiveName')

	@property
	def DisableTriggered(self):
		"""DEPRECATED If enabled, the triggered hello delay function is disabled.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('disableTriggered')

	@property
	def DiscardLearnedRpInfo(self):
		"""DEPRECATED If selected, disregards group mappings learnt from Bootstrap Message (in case not acting as elected BSR) or from Candidate RP Advertisement (in case of elected BSR).

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('discardLearnedRpInfo')

	@property
	def EnableBfdRegistration(self):
		"""DEPRECATED Enable BFD Registration

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('enableBfdRegistration')

	@property
	def EnableBootstrap(self):
		"""DEPRECATED If selected, enables the PIM-SM interface to participate in Bootstrap Router election procedure.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('enableBootstrap')

	@property
	def EnablePrune(self):
		"""DEPRECATED If selected, the LAN Prune (propagation) Delay is enabled for this PIM-SM interface. (This Indicates that this option is present in the Hello message.)

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('enablePrune')

	@property
	def Errors(self):
		"""DEPRECATED A list of errors that have occurred

		Returns:
			list(dict(arg1:str[None|/api/v1/sessions/1/ixnetwork/?deepchild=*],arg2:list[str]))
		"""
		return self._get_attribute('errors')

	@property
	def ForceSemantic(self):
		"""DEPRECATED If enabled, this forces the BSR to send only one group specific RP list per bootstrap message, even if there is space in the packet to push in more RP list information pertaining to a different group.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('forceSemantic')

	@property
	def HelloHoldTime(self):
		"""DEPRECATED The timeout period in seconds specified in Hello messages. It is the length of time the receiver of this message must keep the neighbor reachable. The default is 3.5 times the Hello Interval (105 seconds).

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('helloHoldTime')

	@property
	def HelloInterval(self):
		"""DEPRECATED The PIM-SM Hello Interval is the length of time in seconds between the transmissions of Hello messages. The default is 30 seconds.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('helloInterval')

	@property
	def JoinPrunes(self):
		"""DEPRECATED Number of Join/Prunes

		Returns:
			number
		"""
		return self._get_attribute('joinPrunes')
	@JoinPrunes.setter
	def JoinPrunes(self, value):
		self._set_attribute('joinPrunes', value)

	@property
	def LanPruneTbit(self):
		"""DEPRECATED If selected, the T flag bit in the LAN Prune Delay option of the Hello message is set (= 1). Setting this bit specifies that the sending PIM-SM router has the ability to disable Join message suppression

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('lanPruneTbit')

	@property
	def LearnSelectedRpSet(self):
		"""DEPRECATED If selected, displays the best RP per group (member of selected RP set).

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('learnSelectedRpSet')

	@property
	def LocalRouterId(self):
		"""DEPRECATED The PIM-SM Router ID value, in IPv4 format.

		Returns:
			list(str)
		"""
		return self._get_attribute('localRouterId')

	@property
	def Multiplier(self):
		"""DEPRECATED Number of layer instances per parent instance (multiplier)

		Returns:
			number
		"""
		return self._get_attribute('multiplier')
	@Multiplier.setter
	def Multiplier(self, value):
		self._set_attribute('multiplier', value)

	@property
	def Name(self):
		"""DEPRECATED Name of NGPF element, guaranteed to be unique in Scenario

		Returns:
			str
		"""
		return self._get_attribute('name')
	@Name.setter
	def Name(self, value):
		self._set_attribute('name', value)

	@property
	def OverrideInterval(self):
		"""DEPRECATED (in ms) The delay interval for randomizing the transmission time for override messages-when scheduling a delayed Join message. The default value is 2,500 milliseconds (ms). The valid range is 100 to 7FFF msec. (This is part of the LAN Prune Delay option included in Hello messages).

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('overrideInterval')

	@property
	def PruneDelay(self):
		"""DEPRECATED (in ms) The value of the LAN Prune (propagation) Delay for this PIM-SM interface. The expected delay for messages propagated on the link. It indicates to an upstream router how long to wait for a Join override message before it prunes an interface. The default value is 500 msec. The valid range is 100 to 0x7FFF msec. (LAN Prune Delay is an Option included in Hello messages.)

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('pruneDelay')

	@property
	def SendBidirectional(self):
		"""DEPRECATED If selected, sets the bi-directional PIM-SM flag bit (= 1), per IETF DRAFT draft-ietf-pim-bidir-04. (Note: Designated Forwarder election is not currently supported.)

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('sendBidirectional')

	@property
	def SendGenerationIdOption(self):
		"""DEPRECATED If selected, enables the Send Generation ID Option, and the Generation ID Mode field will become available to make a mode selection.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('sendGenerationIdOption')

	@property
	def SendGenerationMode(self):
		"""DEPRECATED The mode for creating the 32-bit value for the Generation Identifier (GenID) option in the Hello message. A new GenID is created each time an interface (or router) starts or restarts PIM-SM forwarding. A change in this value indicates to the neighbor(s) that a change of state may have occurred, and that the old PIM-SM states information received from those interfaces should be discarded. Choose one of: Incremental-the GenID increases by 1 for each successive Hello Message sent from this emulated PIM-SM router. Random-each Hello message sent from this emulated PIM-SM router will have a randomly-generated GenID. Constant (the default)-the GenID remains the same in all of the Hello Messages sent from this emulated. PIM-SM router.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('sendGenerationMode')

	@property
	def SessionStatus(self):
		"""DEPRECATED Current state of protocol session: Not Started - session negotiation not started, the session is not active yet. Down - actively trying to bring up a protocol session, but negotiation is didn't successfully complete (yet). Up - session came up successfully.

		Returns:
			list(str[down|notStarted|up])
		"""
		return self._get_attribute('sessionStatus')

	@property
	def Sources(self):
		"""DEPRECATED Number of Sources

		Returns:
			number
		"""
		return self._get_attribute('sources')
	@Sources.setter
	def Sources(self, value):
		self._set_attribute('sources', value)

	@property
	def StackedLayers(self):
		"""DEPRECATED List of secondary (many to one) child layer protocols

		Returns:
			list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])
		"""
		return self._get_attribute('stackedLayers')
	@StackedLayers.setter
	def StackedLayers(self, value):
		self._set_attribute('stackedLayers', value)

	@property
	def StateCounts(self):
		"""DEPRECATED A list of values that indicates the total number of sessions, the number of sessions not started, the number of sessions down and the number of sessions that are up

		Returns:
			dict(total:number,notStarted:number,down:number,up:number)
		"""
		return self._get_attribute('stateCounts')

	@property
	def Status(self):
		"""DEPRECATED Running status of associated network element. Once in Started state, protocol sessions will begin to negotiate.

		Returns:
			str(configured|error|mixed|notStarted|started|starting|stopping)
		"""
		return self._get_attribute('status')

	@property
	def SupportUnicastBsm(self):
		"""DEPRECATED If enabled, this supports the sending and processing of Unicast bootstrap messages.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('supportUnicastBsm')

	@property
	def TriggeredHelloDelay(self):
		"""DEPRECATED The time (in seconds) after which the router senses a delay in sending or receiving PIM-SM hello message.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('triggeredHelloDelay')

	@property
	def V4Neighbor(self):
		"""DEPRECATED (Auto Pick Neighbor must be disabled/not selected to make this field active) The user can manually type in the link-local address to be used for the Upstream Neighbor address field in the Join/Prune message.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('v4Neighbor')

	def update(self, ConnectedVia=None, CrpRanges=None, JoinPrunes=None, Multiplier=None, Name=None, Sources=None, StackedLayers=None):
		"""Updates a child instance of pimV4Interface on the server.

		This method has some named parameters with a type: obj (Multivalue).
		The Multivalue class has the associated documentation that details the possible values for those named parameters.

		Args:
			ConnectedVia (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of layers this layer used to connect to the wire
			CrpRanges (number): Number of C-RP Ranges
			JoinPrunes (number): Number of Join/Prunes
			Multiplier (number): Number of layer instances per parent instance (multiplier)
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario
			Sources (number): Number of Sources
			StackedLayers (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of secondary (many to one) child layer protocols

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, ConnectedVia=None, CrpRanges=None, JoinPrunes=None, Multiplier=None, Name=None, Sources=None, StackedLayers=None):
		"""Adds a new pimV4Interface node on the server and retrieves it in this instance.

		Args:
			ConnectedVia (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of layers this layer used to connect to the wire
			CrpRanges (number): Number of C-RP Ranges
			JoinPrunes (number): Number of Join/Prunes
			Multiplier (number): Number of layer instances per parent instance (multiplier)
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario
			Sources (number): Number of Sources
			StackedLayers (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of secondary (many to one) child layer protocols

		Returns:
			self: This instance with all currently retrieved pimV4Interface data using find and the newly added pimV4Interface data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the pimV4Interface data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, ConnectedVia=None, Count=None, CrpRanges=None, DescriptiveName=None, Errors=None, JoinPrunes=None, LocalRouterId=None, Multiplier=None, Name=None, SessionStatus=None, Sources=None, StackedLayers=None, StateCounts=None, Status=None):
		"""Finds and retrieves pimV4Interface data from the server.

		All named parameters support regex and can be used to selectively retrieve pimV4Interface data from the server.
		By default the find method takes no parameters and will retrieve all pimV4Interface data from the server.

		Args:
			ConnectedVia (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of layers this layer used to connect to the wire
			Count (number): Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group
			CrpRanges (number): Number of C-RP Ranges
			DescriptiveName (str): Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context
			Errors (list(dict(arg1:str[None|/api/v1/sessions/1/ixnetwork/?deepchild=*],arg2:list[str]))): A list of errors that have occurred
			JoinPrunes (number): Number of Join/Prunes
			LocalRouterId (list(str)): The PIM-SM Router ID value, in IPv4 format.
			Multiplier (number): Number of layer instances per parent instance (multiplier)
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario
			SessionStatus (list(str[down|notStarted|up])): Current state of protocol session: Not Started - session negotiation not started, the session is not active yet. Down - actively trying to bring up a protocol session, but negotiation is didn't successfully complete (yet). Up - session came up successfully.
			Sources (number): Number of Sources
			StackedLayers (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of secondary (many to one) child layer protocols
			StateCounts (dict(total:number,notStarted:number,down:number,up:number)): A list of values that indicates the total number of sessions, the number of sessions not started, the number of sessions down and the number of sessions that are up
			Status (str(configured|error|mixed|notStarted|started|starting|stopping)): Running status of associated network element. Once in Started state, protocol sessions will begin to negotiate.

		Returns:
			self: This instance with matching pimV4Interface data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of pimV4Interface data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the pimV4Interface data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)

	def get_device_ids(self, PortNames=None, Active=None, AutoPickNeighbor=None, BootstrapHashMaskLength=None, BootstrapInterval=None, BootstrapPriority=None, BootstrapTimeout=None, DisableTriggered=None, DiscardLearnedRpInfo=None, EnableBfdRegistration=None, EnableBootstrap=None, EnablePrune=None, ForceSemantic=None, HelloHoldTime=None, HelloInterval=None, LanPruneTbit=None, LearnSelectedRpSet=None, OverrideInterval=None, PruneDelay=None, SendBidirectional=None, SendGenerationIdOption=None, SendGenerationMode=None, SupportUnicastBsm=None, TriggeredHelloDelay=None, V4Neighbor=None):
		"""Base class infrastructure that gets a list of pimV4Interface device ids encapsulated by this object.

		Use the optional regex parameters in the method to refine the list of device ids encapsulated by this object.

		Args:
			PortNames (str): optional regex of port names
			Active (str): optional regex of active
			AutoPickNeighbor (str): optional regex of autoPickNeighbor
			BootstrapHashMaskLength (str): optional regex of bootstrapHashMaskLength
			BootstrapInterval (str): optional regex of bootstrapInterval
			BootstrapPriority (str): optional regex of bootstrapPriority
			BootstrapTimeout (str): optional regex of bootstrapTimeout
			DisableTriggered (str): optional regex of disableTriggered
			DiscardLearnedRpInfo (str): optional regex of discardLearnedRpInfo
			EnableBfdRegistration (str): optional regex of enableBfdRegistration
			EnableBootstrap (str): optional regex of enableBootstrap
			EnablePrune (str): optional regex of enablePrune
			ForceSemantic (str): optional regex of forceSemantic
			HelloHoldTime (str): optional regex of helloHoldTime
			HelloInterval (str): optional regex of helloInterval
			LanPruneTbit (str): optional regex of lanPruneTbit
			LearnSelectedRpSet (str): optional regex of learnSelectedRpSet
			OverrideInterval (str): optional regex of overrideInterval
			PruneDelay (str): optional regex of pruneDelay
			SendBidirectional (str): optional regex of sendBidirectional
			SendGenerationIdOption (str): optional regex of sendGenerationIdOption
			SendGenerationMode (str): optional regex of sendGenerationMode
			SupportUnicastBsm (str): optional regex of supportUnicastBsm
			TriggeredHelloDelay (str): optional regex of triggeredHelloDelay
			V4Neighbor (str): optional regex of v4Neighbor

		Returns:
			list(int): A list of device ids that meets the regex criteria provided in the method parameters

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._get_ngpf_device_ids(locals())

	def ClearLearnedInfo(self, *args, **kwargs):
		"""Executes the clearLearnedInfo operation on the server.

		Clear Learned Info

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		clearLearnedInfo()

		clearLearnedInfo(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		clearLearnedInfo(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		clearLearnedInfo(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('clearLearnedInfo', payload=payload, response_object=None)

	def FetchAndUpdateConfigFromCloud(self, *args, **kwargs):
		"""Executes the fetchAndUpdateConfigFromCloud operation on the server.

		fetchAndUpdateConfigFromCloud(Mode:string)
			Args:
				args[0] is Mode (str): 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('fetchAndUpdateConfigFromCloud', payload=payload, response_object=None)

	def GetLearnedInfo(self, *args, **kwargs):
		"""Executes the getLearnedInfo operation on the server.

		Get Learned Info

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		getLearnedInfo()

		getLearnedInfo(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		getLearnedInfo(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		getLearnedInfo(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('getLearnedInfo', payload=payload, response_object=None)

	def IncrementGenID(self, *args, **kwargs):
		"""Executes the incrementGenID operation on the server.

		Increment GenID

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		incrementGenID()

		incrementGenID(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		incrementGenID(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('incrementGenID', payload=payload, response_object=None)

	def IncrementGenId(self, *args, **kwargs):
		"""Executes the incrementGenId operation on the server.

		Stops the protocol state machine for the given protocol session instances.

		incrementGenId(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('incrementGenId', payload=payload, response_object=None)

	def RestartDown(self, *args, **kwargs):
		"""Executes the restartDown operation on the server.

		Stop and start interfaces and sessions that are in Down state.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		restartDown()

		restartDown(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		restartDown(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('restartDown', payload=payload, response_object=None)

	def ResumeBSM(self, *args, **kwargs):
		"""Executes the resumeBSM operation on the server.

		Resume Bootstrap

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		resumeBSM()

		resumeBSM(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		resumeBSM(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		resumeBSM(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('resumeBSM', payload=payload, response_object=None)

	def ResumeHello(self, *args, **kwargs):
		"""Executes the resumeHello operation on the server.

		Resume Hello

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		resumeHello()

		resumeHello(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		resumeHello(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		resumeHello(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('resumeHello', payload=payload, response_object=None)

	def SendBSM(self, *args, **kwargs):
		"""Executes the sendBSM operation on the server.

		Stop Bootstrap

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		sendBSM()

		sendBSM(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		sendBSM(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		sendBSM(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('sendBSM', payload=payload, response_object=None)

	def Start(self, *args, **kwargs):
		"""Executes the start operation on the server.

		Activate Interface

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		start()

		start(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		start(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('start', payload=payload, response_object=None)

	def Stop(self, *args, **kwargs):
		"""Executes the stop operation on the server.

		Deactivate Interface

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		stop()

		stop(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		stop(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('stop', payload=payload, response_object=None)

	def StopBSM(self, *args, **kwargs):
		"""Executes the stopBSM operation on the server.

		Stop Bootstrap

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		stopBSM()

		stopBSM(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		stopBSM(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		stopBSM(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('stopBSM', payload=payload, response_object=None)

	def StopHello(self, *args, **kwargs):
		"""Executes the stopHello operation on the server.

		Stop Hello

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		stopHello()

		stopHello(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		stopHello(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('stopHello', payload=payload, response_object=None)

	def Stophello(self, *args, **kwargs):
		"""Executes the stophello operation on the server.

		Stops the protocol state machine for the given protocol session instances.

		stophello(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('stophello', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class InterfaceGroup(Base):
	"""The InterfaceGroup class encapsulates a user managed interfaceGroup node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the InterfaceGroup property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'interfaceGroup'

	def __init__(self, parent):
		super(InterfaceGroup, self).__init__(parent)

	@property
	def Interface(self):
		"""An instance of the Interface class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.static.interfacegroup.interface.interface.Interface)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.static.interfacegroup.interface.interface import Interface
		return Interface(self)

	@property
	def AtmEncapsulation(self):
		"""The type of ATM encapsulation used for the Protocol Interfaces in this Group.

		Returns:
			str(vcMuxIpv4Routed|vcMuxIpv6Routed|vcMuxBridgedEth802p3WithFcs|vcMuxBridgedEth802p3WithOutFcs|llcRoutedAal5Snap|llcBridgedEthernetWithFcs|llcBridgedEthernetWithoutFcs)
		"""
		return self._get_attribute('atmEncapsulation')
	@AtmEncapsulation.setter
	def AtmEncapsulation(self, value):
		self._set_attribute('atmEncapsulation', value)

	@property
	def Description(self):
		"""A brief description of the Interface Group.

		Returns:
			str
		"""
		return self._get_attribute('description')
	@Description.setter
	def Description(self, value):
		self._set_attribute('description', value)

	@property
	def EnableVlan(self):
		"""Enables the use of VLANs.

		Returns:
			bool
		"""
		return self._get_attribute('enableVlan')
	@EnableVlan.setter
	def EnableVlan(self, value):
		self._set_attribute('enableVlan', value)

	@property
	def Enabled(self):
		"""Enables this Interface Group.

		Returns:
			bool
		"""
		return self._get_attribute('enabled')
	@Enabled.setter
	def Enabled(self, value):
		self._set_attribute('enabled', value)

	@property
	def Ip(self):
		"""The IP version being used for the Protocol Interfaces in this Group.

		Returns:
			str(ipv4|ipv6)
		"""
		return self._get_attribute('ip')
	@Ip.setter
	def Ip(self, value):
		self._set_attribute('ip', value)

	@property
	def TrafficGroupId(self):
		"""The name of the group to which this port is assigned, for the purpose of creating traffic streams among source/destination members of the group.

		Returns:
			str(None|/api/v1/sessions/1/ixnetwork/traffic?deepchild=trafficGroup)
		"""
		return self._get_attribute('trafficGroupId')
	@TrafficGroupId.setter
	def TrafficGroupId(self, value):
		self._set_attribute('trafficGroupId', value)

	def update(self, AtmEncapsulation=None, Description=None, EnableVlan=None, Enabled=None, Ip=None, TrafficGroupId=None):
		"""Updates a child instance of interfaceGroup on the server.

		Args:
			AtmEncapsulation (str(vcMuxIpv4Routed|vcMuxIpv6Routed|vcMuxBridgedEth802p3WithFcs|vcMuxBridgedEth802p3WithOutFcs|llcRoutedAal5Snap|llcBridgedEthernetWithFcs|llcBridgedEthernetWithoutFcs)): The type of ATM encapsulation used for the Protocol Interfaces in this Group.
			Description (str): A brief description of the Interface Group.
			EnableVlan (bool): Enables the use of VLANs.
			Enabled (bool): Enables this Interface Group.
			Ip (str(ipv4|ipv6)): The IP version being used for the Protocol Interfaces in this Group.
			TrafficGroupId (str(None|/api/v1/sessions/1/ixnetwork/traffic?deepchild=trafficGroup)): The name of the group to which this port is assigned, for the purpose of creating traffic streams among source/destination members of the group.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, AtmEncapsulation=None, Description=None, EnableVlan=None, Enabled=None, Ip=None, TrafficGroupId=None):
		"""Adds a new interfaceGroup node on the server and retrieves it in this instance.

		Args:
			AtmEncapsulation (str(vcMuxIpv4Routed|vcMuxIpv6Routed|vcMuxBridgedEth802p3WithFcs|vcMuxBridgedEth802p3WithOutFcs|llcRoutedAal5Snap|llcBridgedEthernetWithFcs|llcBridgedEthernetWithoutFcs)): The type of ATM encapsulation used for the Protocol Interfaces in this Group.
			Description (str): A brief description of the Interface Group.
			EnableVlan (bool): Enables the use of VLANs.
			Enabled (bool): Enables this Interface Group.
			Ip (str(ipv4|ipv6)): The IP version being used for the Protocol Interfaces in this Group.
			TrafficGroupId (str(None|/api/v1/sessions/1/ixnetwork/traffic?deepchild=trafficGroup)): The name of the group to which this port is assigned, for the purpose of creating traffic streams among source/destination members of the group.

		Returns:
			self: This instance with all currently retrieved interfaceGroup data using find and the newly added interfaceGroup data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the interfaceGroup data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, AtmEncapsulation=None, Description=None, EnableVlan=None, Enabled=None, Ip=None, TrafficGroupId=None):
		"""Finds and retrieves interfaceGroup data from the server.

		All named parameters support regex and can be used to selectively retrieve interfaceGroup data from the server.
		By default the find method takes no parameters and will retrieve all interfaceGroup data from the server.

		Args:
			AtmEncapsulation (str(vcMuxIpv4Routed|vcMuxIpv6Routed|vcMuxBridgedEth802p3WithFcs|vcMuxBridgedEth802p3WithOutFcs|llcRoutedAal5Snap|llcBridgedEthernetWithFcs|llcBridgedEthernetWithoutFcs)): The type of ATM encapsulation used for the Protocol Interfaces in this Group.
			Description (str): A brief description of the Interface Group.
			EnableVlan (bool): Enables the use of VLANs.
			Enabled (bool): Enables this Interface Group.
			Ip (str(ipv4|ipv6)): The IP version being used for the Protocol Interfaces in this Group.
			TrafficGroupId (str(None|/api/v1/sessions/1/ixnetwork/traffic?deepchild=trafficGroup)): The name of the group to which this port is assigned, for the purpose of creating traffic streams among source/destination members of the group.

		Returns:
			self: This instance with matching interfaceGroup data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of interfaceGroup data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the interfaceGroup data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class BgpEpePeerList(Base):
	"""The BgpEpePeerList class encapsulates a required bgpEpePeerList node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the BgpEpePeerList property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'bgpEpePeerList'

	def __init__(self, parent):
		super(BgpEpePeerList, self).__init__(parent)

	@property
	def BgpEpePeerLinkList(self):
		"""An instance of the BgpEpePeerLinkList class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.bgpepepeerlinklist.BgpEpePeerLinkList)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.bgpepepeerlinklist import BgpEpePeerLinkList
		return BgpEpePeerLinkList(self)._select()

	@property
	def BgpEpePeerSetList(self):
		"""An instance of the BgpEpePeerSetList class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.bgpepepeersetlist.BgpEpePeerSetList)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.bgpepepeersetlist import BgpEpePeerSetList
		return BgpEpePeerSetList(self)

	@property
	def Active(self):
		"""Activate/Deactivate Configuration

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('active')

	@property
	def BBit(self):
		"""B-Flag:Backup Flag.If set, the SID refers to a path that is eligible for protection.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('bBit')

	@property
	def BgpLocalRouterId(self):
		"""BGP Router ID for Local Node Descriptor

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('bgpLocalRouterId')

	@property
	def BgpRemoteRouterId(self):
		"""BGP Router ID for Remote Node Descriptor

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('bgpRemoteRouterId')

	@property
	def Count(self):
		"""Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group

		Returns:
			number
		"""
		return self._get_attribute('count')

	@property
	def DescriptiveName(self):
		"""Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context

		Returns:
			str
		"""
		return self._get_attribute('descriptiveName')

	@property
	def EnablePeerNodeSid(self):
		"""Enable Peer-Node-SID

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('enablePeerNodeSid')

	@property
	def LBit(self):
		"""L-Flag: Local Flag. If set, then the value/index carried by the SID has local significance.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('lBit')

	@property
	def LocalAsn(self):
		"""AS# of Egress node

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('localAsn')

	@property
	def Name(self):
		"""Name of NGPF element, guaranteed to be unique in Scenario

		Returns:
			str
		"""
		return self._get_attribute('name')
	@Name.setter
	def Name(self, value):
		self._set_attribute('name', value)

	@property
	def NoOfPeerSet(self):
		"""Number of EPE Peer Set

		Returns:
			number
		"""
		return self._get_attribute('noOfPeerSet')
	@NoOfPeerSet.setter
	def NoOfPeerSet(self, value):
		self._set_attribute('noOfPeerSet', value)

	@property
	def NoOflinks(self):
		"""Number of Links

		Returns:
			number
		"""
		return self._get_attribute('noOflinks')
	@NoOflinks.setter
	def NoOflinks(self, value):
		self._set_attribute('noOflinks', value)

	@property
	def PBit(self):
		"""P-Flag: Persistent Flag: If set, the SID is persistently allocated, i.e. the SID value remains consistent across router restart and session/interface flap

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('pBit')

	@property
	def PeerName(self):
		"""Peer Name For Reference

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('peerName')

	@property
	def PeerSetGroup(self):
		"""Peer Set Group

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('peerSetGroup')

	@property
	def RemoteAsn(self):
		"""AS# of Peer Node

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('remoteAsn')

	@property
	def Reserved(self):
		"""Reserved

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('reserved')

	@property
	def RsvdBits(self):
		"""Reserved for future use and MUST be zero when originated and ignored when received

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('rsvdBits')

	@property
	def SidIndex(self):
		"""Local Label for Peer-Node

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('sidIndex')

	@property
	def SidIndexValue(self):
		"""If Local Label type is SID, max value is 16777215 and for Index max value is 4294967295

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('sidIndexValue')

	@property
	def UseLocalConfedId(self):
		"""Use Local Confederation identifier

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('useLocalConfedId')

	@property
	def UseRemoteConfedId(self):
		"""Use Remote Confederation identifier

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('useRemoteConfedId')

	@property
	def VBit(self):
		"""V-Flag: Value flag. If set, then the SID carries a label value.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('vBit')

	@property
	def Weight(self):
		"""Weight of SID for Load Balancing

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('weight')

	def update(self, Name=None, NoOfPeerSet=None, NoOflinks=None):
		"""Updates a child instance of bgpEpePeerList on the server.

		This method has some named parameters with a type: obj (Multivalue).
		The Multivalue class has the associated documentation that details the possible values for those named parameters.

		Args:
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario
			NoOfPeerSet (number): Number of EPE Peer Set
			NoOflinks (number): Number of Links

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def get_device_ids(self, PortNames=None, Active=None, BBit=None, BgpLocalRouterId=None, BgpRemoteRouterId=None, EnablePeerNodeSid=None, LBit=None, LocalAsn=None, PBit=None, PeerName=None, PeerSetGroup=None, RemoteAsn=None, Reserved=None, RsvdBits=None, SidIndex=None, SidIndexValue=None, UseLocalConfedId=None, UseRemoteConfedId=None, VBit=None, Weight=None):
		"""Base class infrastructure that gets a list of bgpEpePeerList device ids encapsulated by this object.

		Use the optional regex parameters in the method to refine the list of device ids encapsulated by this object.

		Args:
			PortNames (str): optional regex of port names
			Active (str): optional regex of active
			BBit (str): optional regex of bBit
			BgpLocalRouterId (str): optional regex of bgpLocalRouterId
			BgpRemoteRouterId (str): optional regex of bgpRemoteRouterId
			EnablePeerNodeSid (str): optional regex of enablePeerNodeSid
			LBit (str): optional regex of lBit
			LocalAsn (str): optional regex of localAsn
			PBit (str): optional regex of pBit
			PeerName (str): optional regex of peerName
			PeerSetGroup (str): optional regex of peerSetGroup
			RemoteAsn (str): optional regex of remoteAsn
			Reserved (str): optional regex of reserved
			RsvdBits (str): optional regex of rsvdBits
			SidIndex (str): optional regex of sidIndex
			SidIndexValue (str): optional regex of sidIndexValue
			UseLocalConfedId (str): optional regex of useLocalConfedId
			UseRemoteConfedId (str): optional regex of useRemoteConfedId
			VBit (str): optional regex of vBit
			Weight (str): optional regex of weight

		Returns:
			list(int): A list of device ids that meets the regex criteria provided in the method parameters

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._get_ngpf_device_ids(locals())

	def FetchAndUpdateConfigFromCloud(self, *args, **kwargs):
		"""Executes the fetchAndUpdateConfigFromCloud operation on the server.

		fetchAndUpdateConfigFromCloud(Mode:string)
			Args:
				args[0] is Mode (str): 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('fetchAndUpdateConfigFromCloud', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class ImportTarget(Base):
	"""The ImportTarget class encapsulates a required importTarget node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the ImportTarget property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'importTarget'

	def __init__(self, parent):
		super(ImportTarget, self).__init__(parent)

	@property
	def ImportTargetList(self):
		"""DEPRECATED Configures a target attribute to be associated with advertised L3 VPN route ranges.

		Returns:
			list(dict(arg1:str[as|ip|asNumber2],arg2:number,arg3:str,arg4:number))
		"""
		return self._get_attribute('importTargetList')
	@ImportTargetList.setter
	def ImportTargetList(self, value):
		self._set_attribute('importTargetList', value)

	@property
	def ImportTargetListEx(self):
		"""DEPRECATED Configures a list of export targets to be associated with advertised L3 VPN routeranges.

		Returns:
			list(dict(arg1:str[as|ip|asNumber2],arg2:number,arg3:str,arg4:number,arg5:number,arg6:number,arg7:str))
		"""
		return self._get_attribute('importTargetListEx')
	@ImportTargetListEx.setter
	def ImportTargetListEx(self, value):
		self._set_attribute('importTargetListEx', value)

	def update(self, ImportTargetList=None, ImportTargetListEx=None):
		"""Updates a child instance of importTarget on the server.

		Args:
			ImportTargetList (list(dict(arg1:str[as|ip|asNumber2],arg2:number,arg3:str,arg4:number))): Configures a target attribute to be associated with advertised L3 VPN route ranges.
			ImportTargetListEx (list(dict(arg1:str[as|ip|asNumber2],arg2:number,arg3:str,arg4:number,arg5:number,arg6:number,arg7:str))): Configures a list of export targets to be associated with advertised L3 VPN routeranges.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())
